@@ -10,9 +10,9 @@
 # #################################################
 
 assign.plot.colors <-
-function(labels, col = "colors") {
+function(labels, col = "colors", opacity = 1) {
   if(col == "black") {
-    colors.of.pca.graph = "black"
+    vector.of.colors = "black"
   } else {
     color.numeric.values = c(1)
     current.color = 1
@@ -32,19 +32,32 @@ function(labels, col = "colors") {
     color.numeric.values = c(color.numeric.values, current.color)
     }
   # define a vector of available colors, if an appropriate option was chosen
-  if(col == "colors") {
+  if(col == "colors" && opacity >= 1) {
     available.colors = rep(c("red","green","blue","black","orange","purple",
       "darkgrey","brown","maroon4","mediumturquoise","gold4", "deepskyblue",
       "greenyellow","grey","chartreuse4", "khaki", "navy", "palevioletred",
       "darkolivegreen4", "chocolate4", "yellowgreen"),10)
     }
+  if(col == "colors" && opacity < 1) {
+    available.colors = rep(c(
+      rgb(1,0,0,(opacity*0.8)), # red, opacity slightly tuned
+      rgb(0.2,0.8,0,opacity), # green
+      rgb(0,0,1,opacity), # blue
+      rgb(0,0,0,opacity), # black
+      rgb(1,0.7,0,opacity), # yellow/organge
+      rgb(1,0,0.8,opacity), # purple but slightly different
+      rgb(0.5,0.5,0.5,(opacity*0.8)) # dark grey
+      ),40)
+  }
   # define a vector of gray tones, instead of colors
   if(col == "greyscale") {
     number.of.colors.required = max(color.numeric.values)
     available.colors = gray(seq(0,0.7,0.7/(number.of.colors.required-1)))
   }
   # produce the final vector of colors (or gray tones)
-  colors.of.pca.graph = available.colors[c(color.numeric.values)]
+  vector.of.colors = available.colors[c(color.numeric.values)]
   }
-return(colors.of.pca.graph)
+  # assigning names to the colors
+  names(vector.of.colors) = labels
+return(vector.of.colors)
 }
